@@ -24,12 +24,31 @@ from cubicweb.server import hook
 from cubicweb.selectors import is_instance, on_fire_transition
 from cubicweb.hooks import notification
 
+from cubes.vcsfile import hooks as vcsfile
+
 IGNORE_FILES = set( ('README', 'series', 'status', '.hgignore', '.hgtags') )
 
 def fire(patch, trname, comment):
     patch.cw_adapt_to('IWorkflowable').fire_transition(trname, comment)
 
 
+class ForcePatchMIMETypeHook(hook.Hook):
+    __regid__ = 'vcreview.add_version_content_hook'
+    __select__ = hook.Hook.__select__ & is_instance('VersionContent')
+    events = ('before_add_entity',)
+    # ensure we're fired before AddVersionContentHook
+    order = vcsfile.AddVersionContentHook.order - 1
+
+    def __call__(self):
+        vf = self.entity._vc_vf()
+        if vf.repository.patchrepo_of:
+            if vf.name in IGNORE_FILES:
+                self.entity.cw_edited['data_format'] = u'text/plain'
+            else:
+                self.entity.cw_edited['data_format'] = u'text/x-diff'
+            self.entity.cw_edited['data_encoding'] = vf.repository.encoding
+
+
 class LinkOrCreatePatchOp(hook.DataOperationMixIn, hook.Operation):
     """operation to track patch's state according to incoming revisions"""
     containercls = list # operation order matters
