@@ -27,12 +27,13 @@ from cubes.vcsfile.testutils import init_vcsrepo
 class AutomaticWebTest(testlib.AutomaticWebTest):
     no_auto_populate = ('Repository', 'Revision', 'VersionedFile',
                         'VersionContent', 'DeletedVersionContent',
-                        'Patch', 'Comment')
+                        'Patch', 'Comment', 'InsertionPoint',)
     ignored_relations = set(('at_revision', 'parent_revision',
                              'from_repository', 'from_revision',
                              'content_for', 'vc_copy', 'vc_rename',
                              'patch_repository', 'patch_revision',
-                             'nosy_list', 'comments', 'depends_on'))
+                             'nosy_list', 'comments', 'depends_on',
+                             'point_of'))
 
     @classmethod
     def setUpClass(cls):
