@@ -78,10 +78,10 @@ class PatchCreationHooksTC(CubicWebTC):
                 byfile.setdefault(iter(files).next(), []).append(patch)
             else:
                 bypatch[patch] = files
-        self.assertEqual(len(byfile), 3, byfile)
+        self.assertEqual(len(byfile), 4, byfile)
         # bypatch check we're correctly following renaming
         self.assertEqual(len(bypatch), 1)
-        self.assertEqual(len(patches), 6)
+        self.assertEqual(len(patches), 7)
 
         folded = bypatch.keys()[0]
         self.assertEqual(folded.cw_adapt_to('IWorkflowable').state, 'folded')
@@ -196,6 +196,17 @@ remaining tasks:
 
 url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
 
+        self.vcsrepo._cw = self.request()
+        # test mime type enforcement
+        self.assertEqual(
+            self.vcsrepo.versioned_file('', 'patch_no_ext').head.data_format,
+            'text/x-diff')
+        self.assertEqual(
+            self.vcsrepo.versioned_file('', 'series').head.data_format,
+            'text/plain')
+        self.assertEqual(
+            self.vcsrepo.versioned_file('', 'README').head.data_format,
+            'text/plain')
 
 PatchCreationHooksTC.repo_path = osp.join(PatchCreationHooksTC.datadir, u'patchrepo')
 
