@@ -52,7 +52,7 @@ class InsertPointTC(CubicWebTC):
         # XXX use page api
         pi = self.assertWellFormed(self.get_validator(), formstr)
         self.assertTrue(formstr.startswith('<div id="commentASlot"><form '))
-        self.assertTrue(pi.has_tag('input', name="id-subject:A", type="hidden"))
+        self.assertTrue(pi.has_tag('input', name="lid-subject:A", type="hidden"))
         self.assertTrue(pi.has_tag('input', name="point_of-subject:A", type="hidden"))
         self.assertTrue(pi.has_tag('textarea', cols="80", id="content-subject:A"))
 
