@@ -39,6 +39,8 @@ class PatchReviewWorkflowTC(CubicWebTC):
                 self.patch2eid = session.create_entity(
                     'Patch', patch_repository=vcrepo, originator=u'bob <reviewer1@cwo>').eid
                 session.commit(reset_pool=False)
+                self.task1eid = session.create_entity(
+                    'Task', reverse_has_activity=self.patch1eid, title=u'todo 1').eid
 
     def test_wf(self):
         req = self.request()
@@ -64,6 +66,12 @@ class PatchReviewWorkflowTC(CubicWebTC):
             self.commit()
             patch.cw_clear_all_caches()
             self.assertEqual(patch.patch_reviewer[0].eid, self.reviewer2.eid)
+            # create a task and mark the task1 as done
+            task2eid = req.create_entity(
+                'Task', reverse_has_activity=patch, title=u'todo 2').eid
+            task = req.execute('Any X WHERE X eid %(x)s', {'x': self.task1eid}).get_entity(0, 0)
+            task.cw_adapt_to('IWorkflowable').fire_transition('done')
+            self.commit()
         with self.login('reviewer2'):
             req = self.request()
             rset = req.execute('Any X WHERE X eid %(x)s', {'x': self.patch1eid})
@@ -75,6 +83,12 @@ class PatchReviewWorkflowTC(CubicWebTC):
             patch.cw_clear_all_caches()
             self.assertListEqual(sorted(x[0] for x in self.action_submenu(req, rset, 'workflow')),
                                  ['ask rework', 'fold', 'view history', 'view workflow'])
+            # create a task and mark task2 as done
+            task3eid = req.create_entity(
+                'Task', reverse_has_activity=patch, title=u'todo 3').eid
+            task = req.execute('Any X WHERE X eid %(x)s', {'x': task2eid}).get_entity(0, 0)
+            task.cw_adapt_to('IWorkflowable').fire_transition('done')
+            self.commit()
         with self.login('committer'):
             req = self.request()
             rset = req.execute('Any X WHERE X eid %(x)s', {'x': self.patch1eid})
@@ -86,6 +100,10 @@ class PatchReviewWorkflowTC(CubicWebTC):
             patch.cw_clear_all_caches()
             self.assertListEqual(sorted(x[0] for x in self.action_submenu(req, rset, 'workflow')),
                                  ['view history'])
+            # mark task3 as done
+            task = req.execute('Any X WHERE X eid %(x)s', {'x': task3eid}).get_entity(0, 0)
+            task.cw_adapt_to('IWorkflowable').fire_transition('done')
+            self.commit()
 
 
 
